#
# spec file for package python3-gst
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define build_for_python3 1

%if %{build_for_python3}
%define local_py_requires Requires: python(abi) = %py3_ver
%define local_py_sitedir  %{python3_sitearch}
%define local_py_suffix   3
%define local_py_pkg      python3
%define local_lib_ver     3-0
%else
%define local_py_requires %{py_requires}
%define local_py_sitedir  %{py_sitedir}
%define local_py_suffix   2
%define local_py_pkg      python
%define local_lib_ver     2-0
%endif

Name:           python3-gst
%define _name gst-python
Version:        1.8.3
Release:        3.1
Summary:        Python Bindings for GStreamer
License:        LGPL-2.1+
Group:          Development/Languages/Python
Url:            http://www.gstreamer.net/
Source:         http://gstreamer.freedesktop.org/src/gst-python/%{_name}-%{version}.tar.xz
BuildRequires:  gobject-introspection
BuildRequires:  pkgconfig(gstreamer-1.0) >= 1.8.0
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0) >= 1.8.0
%if %{build_for_python3}
BuildRequires:  python3-devel
%else
BuildRequires:  python-devel
%endif
BuildRequires:  pkgconfig(pygobject-3.0) >= 3.0
Requires:       gstreamer >= 1.0.0
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{py_requires}

%description
This module contains a wrapper that allows GStreamer applications to be
written in Python.

%if %{build_for_python3}
%package -n gstreamer-plugin-python
Summary:        GStreamer 1.0 plugin for python
Group:          System/Libraries

%description -n gstreamer-plugin-python
This module contains a wrapper that allows GStreamer applications to be
written in Python.
%endif

%prep
%setup -q -n %{_name}-%{version}

%build
%if %{build_for_python3}
export PYTHON=python3
%endif
%configure \
    --disable-static
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -name '*.la' -delete -print
%if ! %{build_for_python3}
rm %{buildroot}%{_libdir}/gstreamer-1.0/libgstpythonplugin.so
%endif

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc COPYING NEWS TODO
%{local_py_sitedir}/gi/overrides/

%if %{build_for_python3}
%files -n gstreamer-plugin-python
%defattr(-,root,root)
%{_libdir}/gstreamer-1.0/libgstpythonplugin.cpython*.so
%endif

%changelog
* Mon Jan  9 2017 dimstar@opensuse.org
- Add gobject-introspection BuildRequires: needed in order to get
  automatic typelib() Requires added to the package (boo#1017473).
* Wed Aug 24 2016 zaitor@opensuse.org
- Update to version 1.8.3 (boo#996937):
  + No changes, versionbump only.
* Wed Jun 15 2016 zaitor@opensuse.org
- Update to version 1.8.2:
  + No changes, version bump only.
* Thu Apr 21 2016 zaitor@opensuse.org
- Update to version 1.8.1:
  + No changes, version bump only.
* Wed Mar 16 2016 zaitor@opensuse.org
- Update to version 1.8.0:
  + Hardware-accelerated zero-copy video decoding on Android
  + New video capture source for Android using the
    android.hardware.Camera API.
  + Windows Media reverse playback support (ASF/WMV/WMA).
  + New tracing system provides support for more sophisticated
    debugging tools.
  + New high-level GstPlayer playback convenience API.
  + Initial support for the new Vulkan API, see Matthew Waters'
    blog post for more details.
  + Improved Opus audio codec support: Support for more than two
    channels; MPEG-TS demuxer/muxer can now handle Opus;
    sample-accurate encoding/decoding/transmuxing with Ogg,
    Matroska, ISOBMFF (Quicktime/MP4), and MPEG-TS as container;
    new codec utility functions for Opus header and caps handling
    in pbutils library. The Opus encoder/decoder elements were
    also moved to gst-plugins-base (from -bad), and the opus RTP
    depayloader/payloader to -good.
  + GStreamer VAAPI module now released and maintained as part of
    the GStreamer project.
  + Asset proxy support in the GStreamer Editing Services.
- Replace gstreamer-plugins-base-devel for
  pkgconfig(gstreamer-plugins-base-1.0) BuildRequires and version
  it.
- Add explicit pkgconfig(gstreamer-1.0) BuildRequires.
* Sat Feb  6 2016 zaitor@opensuse.org
- Update to version 1.6.2:
  + overrides: fix a few typos in exception messages.
  + python:
  - Check return value of g_module_symbol().
  - Don't call Py_DECREF() on NULL.
  + pythonplugin: Clean up error handling a bit.
* Mon Nov 23 2015 zaitor@opensuse.org
- Update to version 1.6.1:
  + Fix regression creating (Ghost)Pad (bgo#757108).
- Changes from version 1.6.0:
  + tests:
  - Fix tests in python2.
  - Add test_fraction back in the testsuite.
  - Bring back the testsuite and test if the initialization
    override works.
  + overrides:
  - Do not use inspect.signature as it is not avalaible in
    python2.
  - Disable all GStreamer APIs until Gst has been initialized.
  - Try hard to make the query writable in the pad query
    function.
  + Remove INSTALL file.
  + plugin: Name differently between python2 and python3.
* Mon Oct 20 2014 dimstar@opensuse.org
- Update to version 1.4.0:
  + pythonplugin: Fix compiler warning about unused format string
    argument.
* Sat Oct 11 2014 dimstar@opensuse.org
- Update to version 1.3.90:
  + Sync up for releasse with GStreamer 1.4.x.
- Split new subpackage gstreamer-plugin-python, when building for
  python3.
* Thu Sep 11 2014 dimstar@opensuse.org
- Initial package, python gstreamer; bindings for GStreamer 1.0,
  version 1.2.1.
